==> kleinod-0.36-sources.jar: de/pfabulist/kleinod/nio/PathSpec.java <==
package de.pfabulist.kleinod.nio;

import de.pfabulist.kleinod.os.OS;

import java.nio.charset.StandardCharsets;
import java.util.Optional;
import java.util.regex.Pattern;

/**
 * Copyright (c) 2006 - 2016, Stephan Pfab
 * SPDX-License-Identifier: BSD-2-Clause
 */

public interface PathSpec {

    int getMaxPathLength();
    int getPathLength( String str );

    int getMaxFilenameLength();
    int getFilenameLength( String str );

    int compareTo( String a, String b );

//    int getHash( String a );

    class RC {
        public final Optional<String> root;
        public final String path;

        public RC( Optional<String> root, String path ) {
            this.root = root;
            this.path = path;
        }
    }

    RC getRootComponent( String str );

    String getNormalForm( String str );

    String getSeparator();
    Pattern getAllSeparators();

    /**
     * a pattern that checks for illegal chars
     * need not include separators
     * @return
     */
    default Optional<Pattern> getIllegalCharacters() {
        return Optional.empty();
    }

    /**
     * checks for invalid filenames
     * i.e. illegal char
     * but not length
     * @param str
     * @return
     */
    default Optional<String> filenameIsNotValidBecause( String str ) {
        return getIllegalCharacters().
                filter( pat -> pat.matcher( str ).matches() ).
                map( p -> "contains an illegal character " + str );
    }



    static byte[] getBytes( String str ) {
        return str.getBytes( StandardCharsets.UTF_8);
    }


    static PathSpec byOS( OS os ) {
        if ( os.isWindows() ) {
            return new PathSpecWindows();
        }

        if ( os.isOSX() ) {
            return new PathSpecOSX();
        }

        if ( os.isUnix() ) {
            return new PathSpecUnix();
        }

        return new PathSpecDefault();
    }

}

==> kleinod-0.36.3-sources.jar: de/pfabulist/kleinod/nio/PathSpec.java <==
package de.pfabulist.kleinod.nio;

import de.pfabulist.kleinod.os.OS;

import java.nio.charset.StandardCharsets;
import java.util.Optional;
import java.util.regex.Pattern;

/**
 * Copyright (c) 2006 - 2016, Stephan Pfab
 * SPDX-License-Identifier: BSD-2-Clause
 */

public interface PathSpec {

    int getMaxPathLength();
    int getPathLength( String str );

    int getMaxFilenameLength();
    int getFilenameLength( String str );

    default int compareTo( String a, String b ) {
        return getNormalForm( a ).compareTo( getNormalForm( b ));

    }

//    int getHash( String a );

    class RC {
        public final Optional<String> root;
        public final String path;

        public RC( Optional<String> root, String path ) {
            this.root = root;
            this.path = path;
        }
    }

    RC getRootComponent( String str );

    String getNormalForm( String str );

    String getSeparator();
    Pattern getAllSeparators();

    /**
     * a pattern that checks for illegal chars
     * need not include separators
     * @return
     */
    default Optional<Pattern> getIllegalCharacters() {
        return Optional.empty();
    }

    /**
     * checks for invalid filenames
     * i.e. illegal char
     * but not length
     * @param str
     * @return
     */
    default Optional<String> filenameIsNotValidBecause( String str ) {
        return getIllegalCharacters().
                filter( pat -> pat.matcher( str ).matches() ).
                map( p -> "contains an illegal character " + str );
    }




    static PathSpec byOS( OS os ) {
        if ( os.isWindows() ) {
            return new PathSpecWindows();
        }

        if ( os.isOSX() ) {
            return new PathSpecOSX();
        }

        if ( os.isUnix() ) {
            return new PathSpecUnix();
        }

        return new PathSpecDefault();
    }

}
